function T =weight(n,k)
% weight -- generates a coefficient matrix that can scales a WavmatND
%           so that we can reconstruct an original signal from the
%           transform
% Inputs
%     n -- size of the signal
%     k -- depth of transformation. 
% Output
%     T -- (L+1)*n x (L+1)*n matrix with coefficients in diagonal
% Usage
% When a signal S is transformed by a WavmatND, ts=W*S;
% Then W'*T*ts returns the original signal S.
%
    T=eye((k+1)*n);
    row = linspace(1,n,n);
    col = linspace(1,n,n);
    T(row,col)= 2^(-k )*eye(n);
    for u=k:-1:1 
       row = linspace(1,n,n)+n*(u);
       col = linspace(1,n,n)+n*(u);
       T(row,col)= 2^(-(k+1-u) )*eye(n);
    end

end